@@ -217,6 +217,8 @@ atk_bridge_init (gint *argc, gchar **argv[])
       g_error ("Could not initialize Bonobo");
     }
 
+  bonobo_activate ();
+
   /* Create the accessible application server object */
   this_app = spi_application_new (atk_get_root ());
   /*
@@ -275,8 +277,6 @@ spi_atk_bridge_do_registration (void)
       return FALSE;
     }
 
-  bonobo_activate ();
-
   /* Create the accessible application server object */
   if (this_app == NULL)
     this_app = spi_application_new (atk_get_root ());
@@ -598,8 +598,6 @@ deregister_application (BonoboObject *app)
 
   device_event_controller = bonobo_object_release_unref (device_event_controller, &ev);
   registry = bonobo_object_release_unref (registry, &ev);
-  
-  app = bonobo_object_unref (app);
 }
 
 static void
@@ -745,7 +743,6 @@ spi_atk_emit_eventv (const GObject         *gobject,
   AtkObject          *aobject;
   SpiAccessible      *source = NULL;
   Accessibility_Registry registry;
-  const gchar *name;
 #ifdef SPI_BRIDGE_DEBUG
   CORBA_string s = NULL;
 #endif
@@ -773,7 +770,6 @@ spi_atk_emit_eventv (const GObject         *gobject,
       va_end (args);
       return;
     }
-  name = atk_object_get_name (aobject);
   e.type = g_strdup_vprintf (format, args);
   if (source) e.source = BONOBO_OBJREF (source);
   e.detail1 = detail1;
